==> dif-database-repository-2.3.11-7-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/JasperReportTemplateFile.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * JasperReportTemplateFile
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class JasperReportTemplateFile extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** JasperReportTemplateFile attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** fileName column */
        public static final String FILENAME = "fileName";
        /** fileType column */
        public static final String FILETYPE = "fileType";
        /** fileSize column */
        public static final String FILESIZE = "fileSize";
        /** documentId column */
        public static final String DOCUMENTID = "documentId";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("fileName");
            list.add("fileType");
            list.add("fileSize");
            list.add("documentId");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * jasperReportTemplate relation.
         *
         * @return the jasperReportTemplate bean relations attributes.
         */
        public JasperReportTemplate.Relations jasperReportTemplate()
        {
			JasperReportTemplate c = new JasperReportTemplate();
            return c.new Relations(this.buildPath("jasperReportTemplate"));
        }
        
        /**
         * jasperReportTemplates relation.
         *
         * @return the jasperReportTemplates bean relations attributes.
         */
        public JasperReportTemplate.Relations jasperReportTemplates()
        {
			JasperReportTemplate c = new JasperReportTemplate();
            return c.new Relations(this.buildPath("jasperReportTemplates"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the FILENAME path.
         *
         * @return the path
         */
        public String FILENAME()
        {
            return buildPath(Fields.FILENAME);
        }
		/**
         * the FILETYPE path.
         *
         * @return the path
         */
        public String FILETYPE()
        {
            return buildPath(Fields.FILETYPE);
        }
		/**
         * the FILESIZE path.
         *
         * @return the path
         */
        public String FILESIZE()
        {
            return buildPath(Fields.FILESIZE);
        }
		/**
         * the DOCUMENTID path.
         *
         * @return the path
         */
        public String DOCUMENTID()
        {
            return buildPath(Fields.DOCUMENTID);
        }
    }
	
	/** The dummy obj. */
    private static JasperReportTemplateFile dummyObj = new JasperReportTemplateFile();

	/**
     * Get JasperReportTemplateFile Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("jasperReportTemplate".equalsIgnoreCase(attributeName))
            return jasperReportTemplate;
        if ("fileName".equalsIgnoreCase(attributeName))
            return fileName;
        if ("fileType".equalsIgnoreCase(attributeName))
            return fileType;
        if ("fileSize".equalsIgnoreCase(attributeName))
            return fileSize;
        if ("documentId".equalsIgnoreCase(attributeName))
            return documentId;
        if ("jasperReportTemplates".equalsIgnoreCase(attributeName))
            return jasperReportTemplates;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (Long)attributeValue;
        if ("jasperReportTemplate".equalsIgnoreCase(attributeName))
            jasperReportTemplate = (JasperReportTemplate)attributeValue;
        if ("fileName".equalsIgnoreCase(attributeName))
            fileName = (String)attributeValue;
        if ("fileType".equalsIgnoreCase(attributeName))
            fileType = (String)attributeValue;
        if ("fileSize".equalsIgnoreCase(attributeName))
            fileSize = (Long)attributeValue;
        if ("documentId".equalsIgnoreCase(attributeName))
            documentId = (Long)attributeValue;
        if ("jasperReportTemplates".equalsIgnoreCase(attributeName))
            jasperReportTemplates = (Set<JasperReportTemplate>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** jasperReportTemplate private attribute */
    private JasperReportTemplate jasperReportTemplate;

    /** fileName private attribute */
    private String fileName;

    /** fileType private attribute */
    private String fileType;

    /** fileSize private attribute */
    private Long fileSize;

    /** documentId private attribute */
    private Long documentId;

    /** jasperReportTemplates private attribute */
    private Set<JasperReportTemplate> jasperReportTemplates = new HashSet<JasperReportTemplate>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public JasperReportTemplateFile() {
    }

	/** 
	 * minimal constructor
	 *
     * @param jasperReportTemplate
     * @param fileName
     * @param fileType
     * @param fileSize
     * @param documentId
    }
	 */
    public JasperReportTemplateFile(JasperReportTemplate jasperReportTemplate, String fileName, String fileType, Long fileSize, Long documentId) {
        this.jasperReportTemplate = jasperReportTemplate;
        this.fileName = fileName;
        this.fileType = fileType;
        this.fileSize = fileSize;
        this.documentId = documentId;
    }

    /**
     * full constructor
	 *
     * @param jasperReportTemplate
     * @param fileName
     * @param fileType
     * @param fileSize
     * @param documentId
     * @param jasperReportTemplates
     */
    public JasperReportTemplateFile(JasperReportTemplate jasperReportTemplate, String fileName, String fileType, Long fileSize, Long documentId, Set<JasperReportTemplate> jasperReportTemplates) {
        this.jasperReportTemplate = jasperReportTemplate;
        this.fileName = fileName;
        this.fileType = fileType;
        this.fileSize = fileSize;
        this.documentId = documentId;
        this.jasperReportTemplates = jasperReportTemplates;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * jasperReportTemplate getter method
     *
     * @return jasperReportTemplate method
     */
    public JasperReportTemplate getJasperReportTemplate() {
        return this.jasperReportTemplate;
    }
    
    /**       
     * jasperReportTemplate setter method
     *
     * @param jasperReportTemplate
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setJasperReportTemplate(JasperReportTemplate jasperReportTemplate) {
        this.jasperReportTemplate = jasperReportTemplate;
        
        return this;
    }
    /**       
     * fileName getter method
     *
     * @return fileName method
     */
    public String getFileName() {
        return this.fileName;
    }
    
    /**       
     * fileName setter method
     *
     * @param fileName
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileName(String fileName) {
        this.fileName = fileName;
        
        return this;
    }
    /**       
     * fileType getter method
     *
     * @return fileType method
     */
    public String getFileType() {
        return this.fileType;
    }
    
    /**       
     * fileType setter method
     *
     * @param fileType
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileType(String fileType) {
        this.fileType = fileType;
        
        return this;
    }
    /**       
     * fileSize getter method
     *
     * @return fileSize method
     */
    public Long getFileSize() {
        return this.fileSize;
    }
    
    /**       
     * fileSize setter method
     *
     * @param fileSize
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileSize(Long fileSize) {
        this.fileSize = fileSize;
        
        return this;
    }
    /**       
     * documentId getter method
     *
     * @return documentId method
     */
    public Long getDocumentId() {
        return this.documentId;
    }
    
    /**       
     * documentId setter method
     *
     * @param documentId
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setDocumentId(Long documentId) {
        this.documentId = documentId;
        
        return this;
    }
    /**       
     * jasperReportTemplates getter method
     *
     * @return jasperReportTemplates method
     */
    public Set<JasperReportTemplate> getJasperReportTemplates() {
        return this.jasperReportTemplates;
    }
    
    /**       
     * jasperReportTemplates setter method
     *
     * @param jasperReportTemplates
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setJasperReportTemplates(Set<JasperReportTemplate> jasperReportTemplates) {
        this.jasperReportTemplates = jasperReportTemplates;
        
        return this;
    }

    /**
     * Creates a String representation of the JasperReportTemplateFile object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("fileName").append("='").append(getFileName()).append("' ");			
        buffer.append("fileType").append("='").append(getFileType()).append("' ");			
        buffer.append("fileSize").append("='").append(getFileSize()).append("' ");			
        buffer.append("documentId").append("='").append(getDocumentId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the JasperReportTemplateFile object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(JasperReportTemplateFile other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("fileName".equalsIgnoreCase(attributeName))
        	this.fileName = attributeValue;

        if ("fileType".equalsIgnoreCase(attributeName))
        	this.fileType = attributeValue;

        if ("fileSize".equalsIgnoreCase(attributeName))
            this.fileSize = Long.valueOf(attributeValue);

        if ("documentId".equalsIgnoreCase(attributeName))
            this.documentId = Long.valueOf(attributeValue);

    }


}

==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/JasperReportTemplateFile.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * JasperReportTemplateFile
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class JasperReportTemplateFile extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<JasperReportTemplateFile> {

    /** JasperReportTemplateFile attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** fileName column */
        public static final String FILENAME ="fileName";
        /** fileType column */
        public static final String FILETYPE ="fileType";
        /** fileSize column */
        public static final String FILESIZE ="fileSize";
        /** documentId column */
        public static final String DOCUMENTID ="documentId";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("fileName");
            list.add("fileType");
            list.add("fileSize");
            list.add("documentId");

            return list;
        }
    }

    /** Field attributes */
    public static JasperReportTemplateFileFieldAttributes FieldAttributes=new JasperReportTemplateFileFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public JasperReportTemplateFileFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * jasperReportTemplate relation.
         *
         * @return the jasperReportTemplate bean relations attributes.
         */
        public JasperReportTemplate.Relations jasperReportTemplate()
        {
            JasperReportTemplate c = new JasperReportTemplate();
            return c.new Relations(this.buildPath("jasperReportTemplate"));
        }

        /**
         * jasperReportTemplates relation.
         *
         * @return the jasperReportTemplates bean relations attributes.
         */
        public JasperReportTemplate.Relations jasperReportTemplates()
        {
            JasperReportTemplate c = new JasperReportTemplate();
            return c.new Relations(this.buildPath("jasperReportTemplates"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the FILENAME path.
         *
         * @return the path
         */
        public String FILENAME()
        {
            return buildPath(Fields.FILENAME);
        }
        /**
         * the FILETYPE path.
         *
         * @return the path
         */
        public String FILETYPE()
        {
            return buildPath(Fields.FILETYPE);
        }
        /**
         * the FILESIZE path.
         *
         * @return the path
         */
        public String FILESIZE()
        {
            return buildPath(Fields.FILESIZE);
        }
        /**
         * the DOCUMENTID path.
         *
         * @return the path
         */
        public String DOCUMENTID()
        {
            return buildPath(Fields.DOCUMENTID);
        }
    }

    /** The dummy obj. */
    private static JasperReportTemplateFile dummyObj=new JasperReportTemplateFile();

    /**
     * Get JasperReportTemplateFile Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<JasperReportTemplateFile> getDataSet()
    {
        return new HibernateDataSet<JasperReportTemplateFile>(JasperReportTemplateFile.class, HibernateUtil.getSessionFactory("DIFRepository"),
            JasperReportTemplateFile.getPKFieldListAsString(), JasperReportTemplateFile.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<JasperReportTemplateFile> getDataSetInstance()
    {
        return new JasperReportTemplateFile().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("jasperReportTemplate".equalsIgnoreCase(attributeName))
            return jasperReportTemplate;
        if("fileName".equalsIgnoreCase(attributeName))
            return fileName;
        if("fileType".equalsIgnoreCase(attributeName))
            return fileType;
        if("fileSize".equalsIgnoreCase(attributeName))
            return fileSize;
        if("documentId".equalsIgnoreCase(attributeName))
            return documentId;
        if("jasperReportTemplates".equalsIgnoreCase(attributeName))
            return jasperReportTemplates;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("jasperReportTemplate".equalsIgnoreCase(attributeName))
            jasperReportTemplate =(JasperReportTemplate)attributeValue;
        if("fileName".equalsIgnoreCase(attributeName))
            fileName =(String)attributeValue;
        if("fileType".equalsIgnoreCase(attributeName))
            fileType =(String)attributeValue;
        if("fileSize".equalsIgnoreCase(attributeName))
            fileSize =(Long)attributeValue;
        if("documentId".equalsIgnoreCase(attributeName))
            documentId =(Long)attributeValue;
        if("jasperReportTemplates".equalsIgnoreCase(attributeName))
            jasperReportTemplates =(Set<JasperReportTemplate>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** jasperReportTemplate private attribute */
    private JasperReportTemplate jasperReportTemplate;

    /** fileName private attribute */
    private String fileName;

    /** fileType private attribute */
    private String fileType;

    /** fileSize private attribute */
    private Long fileSize;

    /** documentId private attribute */
    private Long documentId;

    /** jasperReportTemplates private attribute */
    private Set<JasperReportTemplate> jasperReportTemplates = new HashSet<JasperReportTemplate>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public JasperReportTemplateFile() {
    }

	/** 
	 * minimal constructor
	 *
     * @param jasperReportTemplate the jasperReportTemplate
     * @param fileName the fileName
     * @param fileType the fileType
     * @param fileSize the fileSize
     * @param documentId the documentId
    }
	 */
    public JasperReportTemplateFile(JasperReportTemplate jasperReportTemplate, String fileName, String fileType, Long fileSize, Long documentId) {
        this.jasperReportTemplate = jasperReportTemplate;
        this.fileName = fileName;
        this.fileType = fileType;
        this.fileSize = fileSize;
        this.documentId = documentId;
    }

    /**
     * full constructor
	 *
     * @param jasperReportTemplate the jasperReportTemplate
     * @param fileName the fileName
     * @param fileType the fileType
     * @param fileSize the fileSize
     * @param documentId the documentId
     * @param jasperReportTemplates the jasperReportTemplates
     */
    public JasperReportTemplateFile(JasperReportTemplate jasperReportTemplate, String fileName, String fileType, Long fileSize, Long documentId, Set<JasperReportTemplate> jasperReportTemplates) {
        this.jasperReportTemplate = jasperReportTemplate;
        this.fileName = fileName;
        this.fileType = fileType;
        this.fileSize = fileSize;
        this.documentId = documentId;
        this.jasperReportTemplates = jasperReportTemplates;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * jasperReportTemplate getter method
     *
     * @return jasperReportTemplate method
     */
    public JasperReportTemplate getJasperReportTemplate() {
        return this.jasperReportTemplate;
    }
    
    /**       
     * jasperReportTemplate setter method
     *
     * @param jasperReportTemplate the jasperReportTemplate
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setJasperReportTemplate(JasperReportTemplate jasperReportTemplate) {
        this.jasperReportTemplate = jasperReportTemplate;
        
        return this;
    }
    /**       
     * fileName getter method
     *
     * @return fileName method
     */
    public String getFileName() {
        return this.fileName;
    }
    
    /**       
     * fileName setter method
     *
     * @param fileName the fileName
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileName(String fileName) {
        this.fileName = fileName;
        
        return this;
    }
    /**       
     * fileType getter method
     *
     * @return fileType method
     */
    public String getFileType() {
        return this.fileType;
    }
    
    /**       
     * fileType setter method
     *
     * @param fileType the fileType
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileType(String fileType) {
        this.fileType = fileType;
        
        return this;
    }
    /**       
     * fileSize getter method
     *
     * @return fileSize method
     */
    public Long getFileSize() {
        return this.fileSize;
    }
    
    /**       
     * fileSize setter method
     *
     * @param fileSize the fileSize
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setFileSize(Long fileSize) {
        this.fileSize = fileSize;
        
        return this;
    }
    /**       
     * documentId getter method
     *
     * @return documentId method
     */
    public Long getDocumentId() {
        return this.documentId;
    }
    
    /**       
     * documentId setter method
     *
     * @param documentId the documentId
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setDocumentId(Long documentId) {
        this.documentId = documentId;
        
        return this;
    }
    /**       
     * jasperReportTemplates getter method
     *
     * @return jasperReportTemplates method
     */
    public Set<JasperReportTemplate> getJasperReportTemplates() {
        return this.jasperReportTemplates;
    }
    
    /**       
     * jasperReportTemplates setter method
     *
     * @param jasperReportTemplates the jasperReportTemplates
     *
     * @return JasperReportTemplateFile modified instance
     */
    public JasperReportTemplateFile setJasperReportTemplates(Set<JasperReportTemplate> jasperReportTemplates) {
        this.jasperReportTemplates = jasperReportTemplates;
        
        return this;
    }

    /**
     * Creates a String representation of the JasperReportTemplateFile object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("fileName").append("='").append(getFileName()).append("' ");			
        buffer.append("fileType").append("='").append(getFileType()).append("' ");			
        buffer.append("fileSize").append("='").append(getFileSize()).append("' ");			
        buffer.append("documentId").append("='").append(getDocumentId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the JasperReportTemplateFile object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(JasperReportTemplateFile other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

        if ("fileName".equalsIgnoreCase(attributeName))
        	this.fileName = attributeValue;

        if ("fileType".equalsIgnoreCase(attributeName))
        	this.fileType = attributeValue;

        if ("fileSize".equalsIgnoreCase(attributeName))
            this.fileSize = Long.valueOf(attributeValue);

        if ("documentId".equalsIgnoreCase(attributeName))
            this.documentId = Long.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static JasperReportTemplateFile getProxy(Session session, Long id)
    {
        return(JasperReportTemplateFile)session.load(JasperReportTemplateFile.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static JasperReportTemplateFile getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        JasperReportTemplateFile result = (JasperReportTemplateFile)session.load(JasperReportTemplateFile.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static JasperReportTemplateFile getInstance(Session session, Long id)
    {
        return(JasperReportTemplateFile)session.get(JasperReportTemplateFile.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static JasperReportTemplateFile getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        JasperReportTemplateFile result = (JasperReportTemplateFile)session.get(JasperReportTemplateFile.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
